@@ -1,12 +1,42 @@
+"""
+Lambda Cloud CLI entry point. Commands include login/logout, instance management, firewall rules,
+SSH key registration, filesystem actions, and self-update tools.
+"""
+
+# ─────────────────────────────────────────────
+# 🔧 Standard library imports
+# ─────────────────────────────────────────────
 import os
-import typer
+import sys
+import time
+import subprocess
+from pathlib import Path
+from datetime import datetime, timedelta
 from typing import Optional
+
+# ─────────────────────────────────────────────
+# 🌐 Third-party libraries
+# ─────────────────────────────────────────────
+import requests
+import typer
+import pkg_resources
+
+# ─────────────────────────────────────────────
+# 📦 Internal modules
+# ─────────────────────────────────────────────
 from lambda_cloud_cli.lambda_api_client import LambdaAPIClient
 from lambda_cloud_cli.config import load_api_key, save_api_key, delete_api_key
 
 app = typer.Typer()
 client=None
 
+UPDATE_CHECK_INTERVAL_HOURS = 24
+UPDATE_CACHE_FILE = Path.home() / ".lambda-cli" / "last_version_check"
+
+# ─────────────────────────────────────────────
+# 🔧 Utility Functions
+# ─────────────────────────────────────────────
+
 def get_client():
     global client
     if client is None:
@@ -17,6 +47,31 @@ def get_client():
         client = LambdaAPIClient(api_key=API_KEY)
     return client
 
+def check_for_updates():
+    package = "lambda-cloud-cli"
+    cache_dir = UPDATE_CACHE_FILE.parent
+    cache_dir.mkdir(parents=True, exist_ok=True)
+
+    # Check timestamp
+    if UPDATE_CACHE_FILE.exists():
+        last_checked = datetime.fromtimestamp(UPDATE_CACHE_FILE.stat().st_mtime)
+        if datetime.now() - last_checked < timedelta(hours=UPDATE_CHECK_INTERVAL_HOURS):
+            return  # ⏱ Too soon, skip check
+
+    try:
+        installed = pkg_resources.get_distribution(package).version
+        response = requests.get(f"https://pypi.org/pypi/{package}/json", timeout=3)
+        latest = response.json()["info"]["version"]
+        if installed != latest:
+            typer.secho(f"📢 A new version is available: {installed} → {latest}", fg=typer.colors.YELLOW)
+            typer.echo("👉 Run `lambda-cli self-update` to upgrade.\n")
+    except Exception:
+        pass  # Silent fail
+
+# ─────────────────────────────────────────────
+# 🚀 CLI Commands
+# ─────────────────────────────────────────────
+
 @app.command(name="login")
 def login():
     """Set your Lambda Cloud API key"""
@@ -74,8 +129,12 @@ def launch_instance(
         typer.secho("✅ Instance launched successfully!", fg=typer.colors.GREEN)
         typer.echo(result)
 
-@app.command(name="update-instance-name")
-def update_instance_name(instance_id: str, new_name: str):
+@app.command(name="update-instance-name", help="Rename an existing instance")
+def update_instance_name(
+    instance_id: str = typer.Option(..., "--instance-id", help="Instance ID to rename"),
+    new_name: str = typer.Option(..., "--new-name", help="New name for the instance")
+):
+    """Renames an instance by its ID"""
     result = get_client().update_instance_name(instance_id, new_name)
     typer.echo(result)
 
@@ -193,6 +252,43 @@ def list_images():
         region = img.get("region", {}).get("name", "unknown")
         typer.echo(f"{img['id']}: {img['name']} ({region})")
 
+@app.command(name="self-update", help="Check for updates and upgrade to the latest version")
+def self_update(yes: bool = typer.Option(False, "--yes", help="Skip confirmation")):
+    """Upgrade lambda-cloud-cli to the latest version from PyPI"""
+    package = "lambda-cloud-cli"
+
+    try:
+        installed = pkg_resources.get_distribution(package).version
+    except pkg_resources.DistributionNotFound:
+        installed = None
+
+    try:
+        latest = requests.get(f"https://pypi.org/pypi/{package}/json", timeout=5).json()["info"]["version"]
+    except Exception:
+        typer.echo("❌ Could not fetch latest version info from PyPI.")
+        raise typer.Exit(code=1)
+
+    typer.echo(f"📦 Installed: {installed or 'Not installed'}")
+    typer.echo(f"🌍 Latest: {latest}")
+
+    if installed == latest:
+        typer.secho("✅ You're already using the latest version.", fg=typer.colors.GREEN)
+        raise typer.Exit()
+
+    if not yes:
+        confirm = typer.confirm(f"⬆️  Update to version {latest}?")
+        if not confirm:
+            typer.echo("🚫 Update cancelled.")
+            raise typer.Exit()
+
+    typer.echo("🔄 Updating...")
+    subprocess.run([
+        sys.executable, "-m", "pip", "install",
+        "--upgrade", "--force-reinstall", "--no-cache-dir", package
+    ])
+    typer.secho("✅ Update complete!", fg=typer.colors.GREEN)
+
 if __name__ == "__main__":
+    check_for_updates()
     app()
 
